@@ -22,6 +22,7 @@ from __future__ import generators
 import os
 import sys
 import urlparse
+import logging
 
 from jhbuild.errors import UsageError, FatalError, DependencyCycleError, CommandError
 
@@ -52,8 +53,7 @@ class ModuleSet:
         for module in self.modules.keys():
             if module.lower() == module_name:
                 if self.config is None or not self.config.quiet_mode:
-                    print >> sys.stderr, uencode(
-                            _('I: fixed case of module \'%(orig)s\' to \'%(new)s\'') % {
+                    logging.info(_('fixed case of module \'%(orig)s\' to \'%(new)s\'') % {
                             'orig': module_name, 'new': module})
                 return self.modules[module]
         raise KeyError(module_name)
@@ -227,7 +227,7 @@ class ModuleSet:
             try:
                 mod = self.modules[modname]
             except KeyError:
-                print >> sys.stderr, _('W: Unknown module:'), modname
+                logging.warning(_('Unknown module:') + ' '+ modname)
                 del modules[0]
                 continue
             if isinstance(mod, MetaModule):
@@ -283,7 +283,7 @@ def load(config, uri=None):
     ms = ModuleSet(config = config)
     for uri in modulesets:
         if '/' not in uri:
-            if config.nonetwork or config.use_local_modulesets:
+            if config.modulesets_dir and config.nonetwork or config.use_local_modulesets:
                 uri = os.path.join(config.modulesets_dir, uri + '.modules')
             else:
                 uri = 'http://git.gnome.org/cgit/jhbuild/plain/modulesets/%s.modules' % uri
@@ -401,6 +401,7 @@ def _parse_module_set(config, uri):
             if moduleset_name:
                 module.tags.append(moduleset_name)
             module.moduleset_name = moduleset_name
+            module.config = config
             moduleset.add(module)
 
     return moduleset
@@ -409,7 +410,7 @@ def warn_local_modulesets(config):
     if config.use_local_modulesets:
         return
 
-    moduleset_local_path = os.path.join(os.path.dirname(__file__), '..', 'modulesets')
+    moduleset_local_path = os.path.join(SRCDIR, 'modulesets')
     if not os.path.exists(moduleset_local_path):
         # moduleset-less checkout
         return
@@ -438,8 +439,8 @@ def warn_local_modulesets(config):
         # no locally modified moduleset
         return
 
-    print >> sys.stderr, uencode(
-            _('I: modulesets were edited locally but jhbuild is configured '\
-              'to get them from subversion, perhaps you need to add '\
+    logging.info(
+            _('Modulesets were edited locally but JHBuild is configured '\
+              'to get them from the network, perhaps you need to add '\
               'use_local_modulesets = True to your .jhbuildrc.'))
 
